#ifndef MESSAGE_H
#define MESSAGE_H

#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

#include "Mes.h"

/**/

typedef enum {
	LANG_KIND_ENGLISH,
	LANG_KIND_JAPANESE,
	LANG_KIND_MAX_N,
} ELangKind;

/**/

void SetMessage( ELangKind nLang );
void SetMessage( WSCstring strLang );
ELangKind GetLangKind( void );
void SetLabel( void );

void PopupError( WSCstring str );
void PopupWarning( WSCstring str );
void PopupMessage( WSCstring str );
void PopupMesCommon( WSCstring strMesType, WSCstring str );

/**/

#endif /* MESSAGE_H */
